@@ -7,9 +7,9 @@ var indexSectionsWithContent =
   4: "abcdefghiklmnopqrstuvw~",
   5: "abcdefhilnprstuw",
   6: "isuv",
-  7: "dn",
+  7: "dnu",
   8: "abcdeimnsuw",
-  9: "abcdeimnopstuv",
+  9: "abcdeimnoprstuv",
   10: "cs",
   11: "abcdeilqst",
   12: "abcdilnq"
